- [ ] Fix graph labels
  - [ ] Make a scrolling legend
- [ ] Usage view
  - [ ] Day to day
  - [ ] Week to week
  - [ ] Month to month
- [ ] Import usage from CSV
- [ ] Be able to estimate plan pricing while tweaking per hour usage values
- [x] Date range for usage view and plan comparison view
- [x] Split view.py into separate files
- [x] Graph plan pricing based on downloaded power usage
- [x] Download power usage from provider (contact only currently)
- [x] Update power usage from provider (contact only currently)
- [x] Download plan pricing automatically
